@@ -4,7 +4,12 @@ from cognite.client import utils
 from cognite.client._api_client import APIClient
 
 from cognite.experimental._constants import LIST_LIMIT_CEILING, LIST_LIMIT_DEFAULT
-from cognite.experimental.data_classes import TransformationJob, TransformationJobList, TransformationJobMetricList
+from cognite.experimental.data_classes import (
+    TransformationJob,
+    TransformationJobList,
+    TransformationJobMetricList,
+    TransformationJobsFilter,
+)
 
 
 class TransformationJobsAPI(APIClient):
@@ -12,13 +17,17 @@ class TransformationJobsAPI(APIClient):
     _LIST_CLASS = TransformationJobList
 
     def list(
-        self, limit: Optional[int] = LIST_LIMIT_DEFAULT, transformation_id: Optional[int] = None
+        self,
+        limit: Optional[int] = LIST_LIMIT_DEFAULT,
+        transformation_id: Optional[int] = None,
+        transformation_external_id: Optional[str] = None,
     ) -> TransformationJobList:
         """`List all running transformation jobs. <https://docs.cognite.com/api/playground/#operation/transformationJobs>`_
 
         Args:
             limit (int): Limits the number of results to be returned. To retrieve all results use limit=-1, default limit is 25.
             transformation_id (int): Filters the results by the internal transformation id.
+            transformation_external_id (str): Filters the results by the external transformation id.
 
         Returns:
             TransformationJobList: List of transformation jobs
@@ -40,13 +49,11 @@ class TransformationJobsAPI(APIClient):
         if limit in [float("inf"), -1, None]:
             limit = LIST_LIMIT_CEILING
 
-        if transformation_id is not None:
-            resource_path = utils._auxiliary.interpolate_and_url_encode(
-                "/transformations/{}/jobs", str(transformation_id)
-            )
-            return self._list(method="GET", limit=limit, resource_path=resource_path)
+        filter = TransformationJobsFilter(
+            transformation_id=transformation_id, transformation_external_id=transformation_external_id
+        ).dump(camel_case=True)
 
-        return self._list(method="GET", limit=limit,)
+        return self._list(method="GET", limit=limit, filter=filter)
 
     def retrieve(self, id: int) -> Optional[TransformationJob]:
         """`Retrieve a single transformation job by id. <https://docs.cognite.com/api/playground/#operation/getTransformationJob>`_
