@@ -5,7 +5,7 @@ from typing import Dict, List, Optional, Union
 from cognite.client.data_classes._base import CogniteFilter, CogniteResource, CogniteResourceList
 from cognite.client.data_classes.shared import TimestampRange
 
-from cognite.experimental._constants import LIST_LIMIT_DEFAULT
+from cognite.experimental._constants import LIST_LIMIT_CEILING, LIST_LIMIT_DEFAULT
 
 
 class Function(CogniteResource):
@@ -116,7 +116,15 @@ class Function(CogniteResource):
         Returns:
             FunctionSchedulesList: List of function schedules
         """
-        return self._cognite_client.functions.schedules.list(function_external_id=self.external_id, limit=limit)
+        schedules_by_external_id = self._cognite_client.functions.schedules.list(
+            function_external_id=self.external_id, limit=limit
+        )
+        schedules_by_id = self._cognite_client.functions.schedules.list(function_id=self.id, limit=limit)
+
+        if limit in [float("inf"), -1, None]:
+            limit = LIST_LIMIT_CEILING
+
+        return (schedules_by_external_id + schedules_by_id)[:limit]
 
     def retrieve_call(self, id: int) -> "FunctionCall":
         """`Retrieve call by id. <https://docs.cognite.com/api/playground/#operation/get-api-playground-projects-project-functions-function_name-calls-call_id>`_
@@ -170,10 +178,12 @@ class FunctionSchedule(CogniteResource):
     Args:
         id (int): Id of the schedule.
         name (str): Name of the function schedule.
+        function_id (int): Id of the function.
         function_external_id (str): External id of the function.
         description (str): Description of the function schedule.
         cron_expression (str): Cron expression
         created_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
+        session_id (int): ID of the session running with the schedule.
         cognite_client (CogniteClient): An optional CogniteClient to associate with this data class.
     """
 
@@ -181,18 +191,22 @@ class FunctionSchedule(CogniteResource):
         self,
         id: int = None,
         name: str = None,
+        function_id: str = None,
         function_external_id: str = None,
         description: str = None,
         created_time: int = None,
         cron_expression: str = None,
+        session_id: int = None,
         cognite_client=None,
     ):
         self.id = id
         self.name = name
+        self.function_id = function_id
         self.function_external_id = function_external_id
         self.description = description
         self.cron_expression = cron_expression
         self.created_time = created_time
+        self.session_id = session_id
         self._cognite_client = cognite_client
 
     def get_input_data(self) -> dict:
@@ -210,11 +224,13 @@ class FunctionSchedulesFilter(CogniteFilter):
     def __init__(
         self,
         name: str = None,
+        function_id: int = None,
         function_external_id: str = None,
         created_time: Union[Dict[str, int], TimestampRange] = None,
         cron_expression: str = None,
     ):
         self.name = name
+        self.function_id = function_id
         self.function_external_id = function_external_id
         self.created_time = created_time
         self.cron_expression = cron_expression
